Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4427)

Unified Diff: chrome/browser/profiles/profile_shortcut_manager_win.cc

Issue 18584011: Rename base::Delete to base::DeleteFile (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/profiles/profile_shortcut_manager_win.cc
diff --git a/chrome/browser/profiles/profile_shortcut_manager_win.cc b/chrome/browser/profiles/profile_shortcut_manager_win.cc
index b0a0937171327c94b59ed8a0199d69c5a207c8d2..cc8c250122bc43304e1f1b870161ecffa793dc44 100644
--- a/chrome/browser/profiles/profile_shortcut_manager_win.cc
+++ b/chrome/browser/profiles/profile_shortcut_manager_win.cc
@@ -292,7 +292,7 @@ void RenameChromeDesktopShortcutForProfile(
const base::FilePath possible_new_system_shortcut =
system_shortcuts_directory.Append(new_shortcut_filename);
if (base::PathExists(possible_new_system_shortcut))
- base::Delete(old_shortcut_path, false);
+ base::DeleteFile(old_shortcut_path, false);
else if (!RenameDesktopShortcut(old_shortcut_path, new_shortcut_path))
DLOG(ERROR) << "Could not rename Windows profile desktop shortcut.";
} else {
@@ -437,9 +437,9 @@ void DeleteDesktopShortcutsAndIconFile(const base::FilePath& profile_path,
BrowserDistribution* distribution = BrowserDistribution::GetDistribution();
for (size_t i = 0; i < shortcuts.size(); ++i) {
// Use base::Delete() instead of ShellUtil::RemoveShortcut(), as the
// latter causes non-profile taskbar shortcuts to be unpinned.
- base::Delete(shortcuts[i], false);
+ base::DeleteFile(shortcuts[i], false);
// Notify the shell that the shortcut was deleted to ensure desktop refresh.
SHChangeNotify(SHCNE_DELETE, SHCNF_PATH, shortcuts[i].value().c_str(),
NULL);
@@ -447,7 +447,7 @@ void DeleteDesktopShortcutsAndIconFile(const base::FilePath& profile_path,
const base::FilePath icon_path =
profile_path.AppendASCII(profiles::internal::kProfileIconFileName);
- base::Delete(icon_path, false);
+ base::DeleteFile(icon_path, false);
// If |ensure_shortcuts_remain| is true and deleting this profile caused the
// last shortcuts to be removed, re-create a regular non-profile shortcut.
« no previous file with comments | « chrome/browser/profiles/profile_shortcut_manager_unittest_win.cc ('k') | chrome/browser/safe_browsing/download_feedback.cc » ('j') | no next file with comments »
@@ -437,9 +437,9 @@ void DeleteDesktopShortcutsAndIconFile(const base::FilePath& profile_path,
BrowserDistribution* distribution = BrowserDistribution::GetDistribution();
for (size_t i = 0; i < shortcuts.size(); ++i) {
- // Use base::Delete() instead of ShellUtil::RemoveShortcut(), as the
+ // Use base::DeleteFile() instead of ShellUtil::RemoveShortcut(), as the
// latter causes non-profile taskbar shortcuts to be unpinned.

Powered by Google App Engine
This is Rietveld 408576698